.. labscript-utils documentation master file, created by
   sphinx-quickstart on Sun May 31 21:24:37 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

labscript-utils
===============

**labscript-utils** contains code shared between multiple programs in the labscript suite. 
This documentation is primarily for developers who might want to use this common code in their own custom features. 

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: DOCUMENTATION

   labconfig
   api/index
   
.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: FURTHER DOCUMENTATION

   components

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: LINKS

   Home Page <http://labscriptsuite.org>
   Source Code <https://github.com/labscript-suite/labscript-utils>
   PyPI <https://pypi.org/project/labscript-utils/>
   Anaconda Cloud <https://anaconda.org/labscript-suite/labscript-utils>
   BitBucket Archive <http://bitbucket-archive.labscriptsuite.org/#!/labscript_suite/labscript_utils>

.. todolist::
